%%
%% This is file `lgienc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ibycus-babel.dtx  (with options: `lgienc')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from lgienc.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file ibycus-babel.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
\ProvidesFile{lgienc.def}%
           [2005/11/23 v3.0 (PH/WaS)]
\DeclareFontEncoding{LGI}{}{}
\DeclareFontSubstitution{LGI}{fib}{m}{n}
\DeclareErrorFont{LGI}{fib}{m}{n}{10}
\endinput
%%
%% End of file `lgienc.def'.
